Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Timeouts ¶
type Timeouts struct {
// Request represents the total timeout including dial / request / redirect steps
Request time.Duration
// TLS represents the maximum amount of time for TLS handshake process
TLS time.Duration
// Dial represents the maximum amount of time for dialing process
Dial time.Duration
// KeepAlive represents the maximum amount of time to keep alive the socket
KeepAlive time.Duration
}
Timeouts represents the supported timeouts
Click to show internal directories.
Click to hide internal directories.